@@ -1559,9 +1559,17 @@ public interface ConnectionProperties {
 	public abstract void setUtf8OutsideBmpIncludedColumnNamePattern(String regexPattern);
 	
 	public abstract boolean getIncludeInnodbStatusInDeadlockExceptions();
-	
+
 	public abstract void setIncludeInnodbStatusInDeadlockExceptions(boolean flag);
 	
+	public abstract boolean getIncludeThreadDumpInDeadlockExceptions();
+	
+	public abstract void setIncludeThreadDumpInDeadlockExceptions(boolean flag);
+	
+	public abstract boolean getIncludeThreadNamesAsStatementComment();
+	
+	public abstract void setIncludeThreadNamesAsStatementComment(boolean flag);
+	
 	public abstract boolean getBlobsAreStrings();
 
 	public abstract void setBlobsAreStrings(boolean flag);
