@@ -1,6 +1,6 @@
 /*
- Copyright  2002-2004 MySQL AB, 2008-2010 Sun Microsystems
- All rights reserved. Use is subject to license terms.
+ Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
+ 
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as
@@ -113,6 +113,8 @@ public class Field {
 	private boolean isSingleBit;
 
 	private int maxBytesPerChar;
+	
+	private final boolean valueNeedsQuoting;
 
 	/**
 	 * Constructor used when communicating with 4.1 and newer servers
@@ -288,6 +290,7 @@ public class Field {
 				break;
 			}
 		}
+		this.valueNeedsQuoting = determineNeedsQuoting();
 	}
 
 	private boolean shouldSetupForUtf8StringInBlob() throws SQLException {
@@ -372,6 +375,7 @@ public class Field {
 		this.sqlType = jdbcType;
 		this.colFlag = 0;
 		this.colDecimals = 0;
+		this.valueNeedsQuoting = determineNeedsQuoting();
 	}
 	
 	/**
@@ -399,6 +403,7 @@ public class Field {
 		this.colFlag = 0;
 		this.colDecimals = 0;
 		this.charsetIndex = charsetIndex;
+		this.valueNeedsQuoting = determineNeedsQuoting();
 		
 		switch (this.sqlType) {
 		case Types.BINARY:
@@ -590,9 +595,13 @@ public class Field {
 
 	public synchronized int getMaxBytesPerCharacter() throws SQLException {
 		if (this.maxBytesPerChar == 0) {
-			this.maxBytesPerChar = this.connection.getMaxBytesPerChar(getCharacterSet());
+			if ((this.charsetIndex == 33) && (this.charsetName.equalsIgnoreCase("UTF-8"))) {
+				//Avoid mix with UTF8MB4 on 5.5.3+
+				this.maxBytesPerChar = 3;
+			} else {
+				this.maxBytesPerChar = this.connection.getMaxBytesPerChar(getCharacterSet());
+			}
 		}
-
 		return this.maxBytesPerChar;
 	}
 
@@ -1050,4 +1059,31 @@ public class Field {
 	protected boolean isSingleBit() {
 		return this.isSingleBit;
 	}
+
+	protected boolean getvalueNeedsQuoting() {
+		return this.valueNeedsQuoting;
+	}
+
+	private boolean determineNeedsQuoting() {
+		boolean retVal = false;
+		
+		switch (this.sqlType) {
+		case Types.BIGINT:
+		case Types.BIT:
+		case Types.DECIMAL:
+		case Types.DOUBLE:
+		case Types.FLOAT:
+		case Types.INTEGER:
+		case Types.NUMERIC:
+		case Types.REAL:
+		case Types.SMALLINT:
+		case Types.TINYINT:
+			retVal = false;
+			break;
+		default: 
+			retVal = true;
+		}
+		return retVal;
+
+	}
 }
