@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -46,7 +46,7 @@ public class LoadBalancedMySQLConnection implements MySQLConnection {
 		return this.proxy;
 	}
 
-	protected MySQLConnection getActiveMySQLConnection() {
+	protected synchronized MySQLConnection getActiveMySQLConnection() {
 		return this.proxy.currentConn;
 	}
 
@@ -1898,11 +1898,6 @@ public class LoadBalancedMySQLConnection implements MySQLConnection {
 		return getActiveMySQLConnection().getMetadataSafeStatement();
 	}
 
-	public Object getMutex() throws SQLException {
-
-		return getActiveMySQLConnection().getMutex();
-	}
-
 	public int getNetBufferLength() {
 
 		return getActiveMySQLConnection().getNetBufferLength();
@@ -1968,7 +1963,7 @@ public class LoadBalancedMySQLConnection implements MySQLConnection {
 		return getActiveMySQLConnection().getStatementInterceptorsInstances();
 	}
 
-	public int getTransactionIsolation() throws SQLException {
+	public synchronized int getTransactionIsolation() throws SQLException {
 
 		return getActiveMySQLConnection().getTransactionIsolation();
 	}
@@ -2513,11 +2508,27 @@ public class LoadBalancedMySQLConnection implements MySQLConnection {
 		
 	}
 
-	public synchronized void setTypeMap(Map map) throws SQLException {
+	public boolean getIncludeThreadDumpInDeadlockExceptions() {
+		return getActiveMySQLConnection().getIncludeThreadDumpInDeadlockExceptions();
+	}
+
+	public void setIncludeThreadDumpInDeadlockExceptions(boolean flag) {
+		getActiveMySQLConnection().setIncludeThreadDumpInDeadlockExceptions(flag);
+	}
+
+	public void setTypeMap(Map<String, Class<?>> map) throws SQLException {
 		getActiveMySQLConnection().setTypeMap(map);
 	}
-	
-	
-	
 
+	public boolean getIncludeThreadNamesAsStatementComment() {
+		return getActiveMySQLConnection().getIncludeThreadNamesAsStatementComment();
+	}
+
+	public void setIncludeThreadNamesAsStatementComment(boolean flag) {
+		getActiveMySQLConnection().setIncludeThreadNamesAsStatementComment(flag);
+	}
+
+	public synchronized boolean isServerLocal() throws SQLException {
+		return getActiveMySQLConnection().isServerLocal();
+	}
 }
