@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2004, 2010, Oracle and/or its affiliates. All rights reserved.
+ Copyright (c) 2004, 2011, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -506,15 +506,6 @@ public class ReplicationConnection implements Connection, PingTarget {
 
 	// For testing
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see java.sql.Connection#setTypeMap(java.util.Map)
-	 */
-	public synchronized void setTypeMap(Map arg0) throws SQLException {
-		this.currentConnection.setTypeMap(arg0);
-	}
-
 	private synchronized void switchToMasterConnection() throws SQLException {
 		swapConnections(this.masterConnection, this.slavesConnection);
 	}
@@ -2458,7 +2449,7 @@ public class ReplicationConnection implements Connection, PingTarget {
       currentConnection.setProxy(proxy);
    }
 
- 	public boolean getRetainStatementAfterResultSetClose() {
+ 	public synchronized boolean getRetainStatementAfterResultSetClose() {
 		return currentConnection.getRetainStatementAfterResultSetClose();
 	}
 
@@ -2541,6 +2532,30 @@ public class ReplicationConnection implements Connection, PingTarget {
 		currentConnection.setLoadBalanceAutoCommitStatementThreshold(loadBalanceAutoCommitStatementThreshold);
 		
 	}
-	
 
+	public void setTypeMap(Map<String, Class<?>> map) throws SQLException {
+		// TODO Auto-generated method stub
+		
+	}
+
+	public boolean getIncludeThreadDumpInDeadlockExceptions() {
+		return currentConnection.getIncludeThreadDumpInDeadlockExceptions();
+	}
+
+	public void setIncludeThreadDumpInDeadlockExceptions(boolean flag) {
+		currentConnection.setIncludeThreadDumpInDeadlockExceptions(flag);
+		
+	}
+
+	public boolean getIncludeThreadNamesAsStatementComment() {
+		return currentConnection.getIncludeThreadNamesAsStatementComment();
+	}
+
+	public void setIncludeThreadNamesAsStatementComment(boolean flag) {
+		currentConnection.setIncludeThreadNamesAsStatementComment(flag);
+	}
+
+	public synchronized boolean isServerLocal() throws SQLException {
+		return this.currentConnection.isServerLocal();
+	}
 }
