@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
+ Copyright (c) 2002, 2011, Oracle and/or its affiliates. All rights reserved.
  
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
@@ -311,9 +311,6 @@ public class ServerPreparedStatement extends PreparedStatement {
 	/** If this statement has been marked invalid, what was the reason? */
 	private SQLException invalidationException;
 
-	/** Does this query modify data? */
-	private boolean isSelectQuery;
-
 	private Buffer outByteBuffer;
 
 	/** Bind values for individual fields */
@@ -353,8 +350,8 @@ public class ServerPreparedStatement extends PreparedStatement {
 
 		try {
 			return (ServerPreparedStatement) JDBC_4_SPS_CTOR.newInstance(new Object[] { conn,
-					sql, catalog, Constants.integerValueOf(resultSetType),
-					Constants.integerValueOf(resultSetConcurrency) });
+					sql, catalog, Integer.valueOf(resultSetType),
+					Integer.valueOf(resultSetConcurrency) });
 		} catch (IllegalArgumentException e) {
 			throw new SQLException(e.toString(), SQLError.SQL_STATE_GENERAL_ERROR);
 		} catch (InstantiationException e) {
@@ -398,8 +395,6 @@ public class ServerPreparedStatement extends PreparedStatement {
 		
 		this.firstCharOfStmt = StringUtils.firstAlphaCharUc(sql, startOfStatement);
 		
-		this.isSelectQuery = 'S' == this.firstCharOfStmt;
-		
 		if (this.connection.versionMeetsMinimum(5, 0, 0)) {
 			this.serverNeedsResetBeforeEachExecution = 
 				!this.connection.versionMeetsMinimum(5, 0, 3);
@@ -463,7 +458,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		this.batchedArgs.add(new BatchedBindValues(this.parameterBindings));
 	}
 
-	protected String asSql(boolean quoteStreamsAndUnknowns) throws SQLException {
+	protected synchronized String asSql(boolean quoteStreamsAndUnknowns) throws SQLException {
 
 		if (this.isClosed) {
 			return "statement has been closed, no further internal information available";
@@ -535,7 +530,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * 
 	 * @see com.mysql.jdbc.Statement#checkClosed()
 	 */
-	protected void checkClosed() throws SQLException {
+	protected synchronized void checkClosed() throws SQLException {
 		if (this.invalid) {
 			throw this.invalidationException;
 		}
@@ -551,7 +546,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		clearParametersInternal(true);
 	}
 
-	private void clearParametersInternal(boolean clearServerParameters)
+	private synchronized void clearParametersInternal(boolean clearServerParameters)
 			throws SQLException {
 		boolean hadLongData = false;
 
@@ -581,7 +576,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 
 	private Calendar defaultTzCalendar;
 
-	protected void setClosed(boolean flag) {
+	protected synchronized void setClosed(boolean flag) {
 		this.isClosed = flag;
 	}
 	
@@ -601,7 +596,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		realClose(true, true);
 	}
 
-	private void dumpCloseForTestcase() {
+	private synchronized void dumpCloseForTestcase() {
 		StringBuffer buf = new StringBuffer();
 		this.connection.generateConnectionCommentBlock(buf);
 		buf.append("DEALLOCATE PREPARE debug_stmt_");
@@ -611,7 +606,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		this.connection.dumpTestcaseQuery(buf.toString());
 	}
 
-	private void dumpExecuteForTestcase() throws SQLException {
+	private synchronized void dumpExecuteForTestcase() throws SQLException {
 		StringBuffer buf = new StringBuffer();
 
 		for (int i = 0; i < this.parameterCount; i++) {
@@ -657,7 +652,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		this.connection.dumpTestcaseQuery(buf.toString());
 	}
 
-	private void dumpPrepareForTestcase() throws SQLException {
+	private synchronized void dumpPrepareForTestcase() throws SQLException {
 
 		StringBuffer buf = new StringBuffer(this.originalSql.length() + 64);
 
@@ -672,7 +667,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		this.connection.dumpTestcaseQuery(buf.toString());
 	}
 
-	protected int[] executeBatchSerially(int batchTimeout) throws SQLException {
+	protected synchronized int[] executeBatchSerially(int batchTimeout) throws SQLException {
 		MySQLConnection locallyScopedConn = this.connection;
 		
 		if (locallyScopedConn == null) {
@@ -688,7 +683,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 
 		checkClosed();
 
-		synchronized (locallyScopedConn.getMutex()) {
+		synchronized (locallyScopedConn) {
 			clearWarnings();
 
 			// Store this for later, we're going to 'swap' them out
@@ -833,7 +828,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @see com.mysql.jdbc.PreparedStatement#executeInternal(int,
 	 *      com.mysql.jdbc.Buffer, boolean, boolean)
 	 */
-	protected com.mysql.jdbc.ResultSetInternalMethods executeInternal(int maxRowsToRetrieve,
+	protected synchronized com.mysql.jdbc.ResultSetInternalMethods executeInternal(int maxRowsToRetrieve,
 			Buffer sendPacket, boolean createStreamingResultSet,
 			boolean queryIsSelectOnly, Field[] metadataFromCache,
 			boolean isBatch)
@@ -917,7 +912,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @return
 	 * @throws SQLException
 	 */
-	protected BindValue getBinding(int parameterIndex, boolean forLongData)
+	protected synchronized BindValue getBinding(int parameterIndex, boolean forLongData)
 			throws SQLException {
 		checkClosed();
 		
@@ -957,7 +952,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	/**
 	 * @see com.mysql.jdbc.PreparedStatement#getBytes(int)
 	 */
-	byte[] getBytes(int parameterIndex) throws SQLException {
+	synchronized byte[] getBytes(int parameterIndex) throws SQLException {
 		BindValue bindValue = getBinding(parameterIndex, false);
 
 		if (bindValue.isNull) {
@@ -992,7 +987,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	/**
 	 * @see java.sql.PreparedStatement#getMetaData()
 	 */
-	public java.sql.ResultSetMetaData getMetaData() throws SQLException {
+	public synchronized java.sql.ResultSetMetaData getMetaData() throws SQLException {
 		checkClosed();
 
 		if (this.resultFields == null) {
@@ -1006,7 +1001,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	/**
 	 * @see java.sql.PreparedStatement#getParameterMetaData()
 	 */
-	public ParameterMetaData getParameterMetaData() throws SQLException {
+	public synchronized ParameterMetaData getParameterMetaData() throws SQLException {
 		checkClosed();
 		
 		if (this.parameterMetaData == null) {
@@ -1034,7 +1029,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @throws SQLException
 	 *             if an error occurs
 	 */
-	protected void realClose(boolean calledExplicitly, 
+	protected synchronized void realClose(boolean calledExplicitly, 
 			boolean closeOpenResults) throws SQLException {
 		if (this.isClosed) {
 			return;
@@ -1059,7 +1054,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 			SQLException exceptionDuringClose = null;
 
 			if (calledExplicitly && !this.connection.isClosed()) {
-				synchronized (this.connection.getMutex()) {
+				synchronized (this.connection) {
 					try {
 
 						MysqlIO mysql = this.connection.getIO();
@@ -1098,7 +1093,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @throws SQLException
 	 *             if an error occurs.
 	 */
-	protected void rePrepare() throws SQLException {
+	protected synchronized void rePrepare() throws SQLException {
 		this.invalidationException = null;
 
 		try {
@@ -1173,10 +1168,10 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * 
 	 * @throws SQLException
 	 */
-	private com.mysql.jdbc.ResultSetInternalMethods serverExecute(int maxRowsToRetrieve,
+	private synchronized com.mysql.jdbc.ResultSetInternalMethods serverExecute(int maxRowsToRetrieve,
 			boolean createStreamingResultSet, 
 			Field[] metadataFromCache) throws SQLException {
-		synchronized (this.connection.getMutex()) {
+		synchronized (this.connection) {
 			MysqlIO mysql = this.connection.getIO();
 
 			if (mysql.shouldIntercept()) {
@@ -1535,9 +1530,9 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @throws SQLException
 	 *             if an error occurs.
 	 */
-	private void serverLongData(int parameterIndex, BindValue longData)
+	private synchronized void serverLongData(int parameterIndex, BindValue longData)
 			throws SQLException {
-		synchronized (this.connection.getMutex()) {
+		synchronized (this.connection) {
 			MysqlIO mysql = this.connection.getIO();
 
 			Buffer packet = mysql.getSharedSendPacket();
@@ -1570,8 +1565,8 @@ public class ServerPreparedStatement extends PreparedStatement {
 		}
 	}
 
-	private void serverPrepare(String sql) throws SQLException {
-		synchronized (this.connection.getMutex()) {
+	private synchronized void serverPrepare(String sql) throws SQLException {
+		synchronized (this.connection) {
 			MysqlIO mysql = this.connection.getIO();
 
 			if (this.connection.getAutoGenerateTestcaseScript()) {
@@ -1692,7 +1687,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		}
 	}
 
-	private String truncateQueryToLog(String sql) {
+	private synchronized String truncateQueryToLog(String sql) {
 		String query = null;
 		
 		if (sql.length() > this.connection.getMaxQuerySizeToLog()) {
@@ -1709,8 +1704,8 @@ public class ServerPreparedStatement extends PreparedStatement {
 		return query;
 	}
 
-	private void serverResetStatement() throws SQLException {
-		synchronized (this.connection.getMutex()) {
+	private synchronized void serverResetStatement() throws SQLException {
+		synchronized (this.connection) {
 
 			MysqlIO mysql = this.connection.getIO();
 
@@ -1748,7 +1743,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @see java.sql.PreparedStatement#setAsciiStream(int, java.io.InputStream,
 	 *      int)
 	 */
-	public void setAsciiStream(int parameterIndex, InputStream x, int length)
+	public synchronized void setAsciiStream(int parameterIndex, InputStream x, int length)
 			throws SQLException {
 		checkClosed();
 
@@ -1773,7 +1768,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	/**
 	 * @see java.sql.PreparedStatement#setBigDecimal(int, java.math.BigDecimal)
 	 */
-	public void setBigDecimal(int parameterIndex, BigDecimal x)
+	public synchronized void setBigDecimal(int parameterIndex, BigDecimal x)
 			throws SQLException {
 		checkClosed();
 
@@ -1800,7 +1795,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @see java.sql.PreparedStatement#setBinaryStream(int, java.io.InputStream,
 	 *      int)
 	 */
-	public void setBinaryStream(int parameterIndex, InputStream x, int length)
+	public synchronized void setBinaryStream(int parameterIndex, InputStream x, int length)
 			throws SQLException {
 		checkClosed();
 
@@ -1825,7 +1820,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	/**
 	 * @see java.sql.PreparedStatement#setBlob(int, java.sql.Blob)
 	 */
-	public void setBlob(int parameterIndex, Blob x) throws SQLException {
+	public synchronized void setBlob(int parameterIndex, Blob x) throws SQLException {
 		checkClosed();
 
 		if (x == null) {
@@ -1890,7 +1885,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @see java.sql.PreparedStatement#setCharacterStream(int, java.io.Reader,
 	 *      int)
 	 */
-	public void setCharacterStream(int parameterIndex, Reader reader, int length)
+	public synchronized void setCharacterStream(int parameterIndex, Reader reader, int length)
 			throws SQLException {
 		checkClosed();
 
@@ -1915,7 +1910,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	/**
 	 * @see java.sql.PreparedStatement#setClob(int, java.sql.Clob)
 	 */
-	public void setClob(int parameterIndex, Clob x) throws SQLException {
+	public synchronized void setClob(int parameterIndex, Clob x) throws SQLException {
 		checkClosed();
 
 		if (x == null) {
@@ -1983,7 +1978,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	/**
 	 * @see java.sql.PreparedStatement#setDouble(int, double)
 	 */
-	public void setDouble(int parameterIndex, double x) throws SQLException {
+	public synchronized void setDouble(int parameterIndex, double x) throws SQLException {
 		checkClosed();
 
 		if (!this.connection.getAllowNanAndInf()
@@ -2144,7 +2139,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @throws SQLException
 	 *             if a database access error occurs
 	 */
-	public void setTime(int parameterIndex, java.sql.Time x)
+	public synchronized void setTime(int parameterIndex, java.sql.Time x)
 			throws SQLException {
 		setTimeInternal(parameterIndex, x, null, this.connection.getDefaultTimeZone(), false);
 	}
@@ -2184,7 +2179,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @throws SQLException
 	 *             if a database access error occurs
 	 */
-	public void setTimeInternal(int parameterIndex, java.sql.Time x,
+	protected synchronized void setTimeInternal(int parameterIndex, java.sql.Time x,
 			Calendar targetCalendar,
 			TimeZone tz, boolean rollForward) throws SQLException {
 		if (x == null) {
@@ -2225,7 +2220,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @throws SQLException
 	 *             if a database-access error occurs.
 	 */
-	public void setTimestamp(int parameterIndex, java.sql.Timestamp x)
+	public synchronized void setTimestamp(int parameterIndex, java.sql.Timestamp x)
 			throws SQLException {
 		setTimestampInternal(parameterIndex, x, null, this.connection.getDefaultTimeZone(), false);
 	}
@@ -2249,7 +2244,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		setTimestampInternal(parameterIndex, x, cal, cal.getTimeZone(), true);
 	}
 
-	protected void setTimestampInternal(int parameterIndex,
+	protected synchronized void setTimestampInternal(int parameterIndex,
 			java.sql.Timestamp x, Calendar targetCalendar,
 			TimeZone tz, boolean rollForward)
 			throws SQLException {
@@ -2281,7 +2276,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		}
 	}
 
-	protected void setType(BindValue oldValue, int bufferType) {
+	protected synchronized void setType(BindValue oldValue, int bufferType) {
 		if (oldValue.bufferType != bufferType) {
 			this.sendTypesToServer = true;
 		}
@@ -2335,7 +2330,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * @throws SQLException
 	 *             DOCUMENT ME!
 	 */
-	private void storeBinding(Buffer packet, BindValue bindValue, MysqlIO mysql)
+	private synchronized void storeBinding(Buffer packet, BindValue bindValue, MysqlIO mysql)
 			throws SQLException {
 		try {
 			Object value = bindValue.value;
@@ -2405,7 +2400,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		}
 	}
 
-	private void storeDateTime412AndOlder(Buffer intoBuf, java.util.Date dt, int bufferType)
+	private synchronized void storeDateTime412AndOlder(Buffer intoBuf, java.util.Date dt, int bufferType)
 			throws SQLException {
 		
 		Calendar sessionCalendar = null;
@@ -2457,7 +2452,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		}
 	}
 
-	private void storeDateTime(Buffer intoBuf, java.util.Date dt, MysqlIO mysql, int bufferType)
+	private synchronized void storeDateTime(Buffer intoBuf, java.util.Date dt, MysqlIO mysql, int bufferType)
 			throws SQLException {
 		if (this.connection.versionMeetsMinimum(4, 1, 3)) {
 			storeDateTime413AndNewer(intoBuf, dt, bufferType);
@@ -2466,7 +2461,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		}
 	}
 
-	private void storeDateTime413AndNewer(Buffer intoBuf, java.util.Date dt, int bufferType)
+	private synchronized void storeDateTime413AndNewer(Buffer intoBuf, java.util.Date dt, int bufferType)
 			throws SQLException {
 		Calendar sessionCalendar = null;
 		
@@ -2559,7 +2554,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	//
 	// TO DO: Investigate using NIO to do this faster
 	//
-	private void storeReader(MysqlIO mysql, int parameterIndex, Buffer packet,
+	private synchronized void storeReader(MysqlIO mysql, int parameterIndex, Buffer packet,
 			Reader inStream) throws SQLException {
 		String forcedEncoding = this.connection.getClobCharacterEncoding();
 		
@@ -2655,7 +2650,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		}
 	}
 
-	private void storeStream(MysqlIO mysql, int parameterIndex, Buffer packet,
+	private synchronized void storeStream(MysqlIO mysql, int parameterIndex, Buffer packet,
 			InputStream inStream) throws SQLException {
 		byte[] buf = new byte[BLOB_STREAM_READ_BUF_SIZE];
 
@@ -2823,7 +2818,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 *  Computes the maximum parameter set size, and entire batch size given 
 	 *  the number of arguments in the batch.
 	 */
-	protected long[] computeMaxParameterSetSizeAndBatchSize(int numBatchedArgs) {
+	protected synchronized long[] computeMaxParameterSetSizeAndBatchSize(int numBatchedArgs) {
 		long sizeOfEntireBatch = 1 + /* com_execute */ + 4 /* stmt id */ + 1 /* flags */ + 4 /* batch count padding */; 
 		long maxSizeOfParameterSet = 0;
 		
@@ -2967,7 +2962,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		return this.hasOnDuplicateKeyUpdate;
 	}
 	
-	protected PreparedStatement prepareBatchedInsertSQL(MySQLConnection localConn, int numBatches) throws SQLException {
+	protected synchronized PreparedStatement prepareBatchedInsertSQL(MySQLConnection localConn, int numBatches) throws SQLException {
 		try {
 			PreparedStatement pstmt = new ServerPreparedStatement(localConn, this.parseInfo.getSqlForBatch(numBatches), this.currentCatalog, this.resultSetConcurrency, this.resultSetType);
 			pstmt.setRetrieveGeneratedKeys(this.retrieveGeneratedKeys);
