@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
+ Copyright (c) 2002, 2011, Oracle and/or its affiliates. All rights reserved.
  
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
@@ -32,6 +32,9 @@ import java.lang.reflect.Method;
 import java.net.InetAddress;
 import java.net.Socket;
 import java.net.SocketException;
+import java.net.UnknownHostException;
+import java.sql.ResultSet;
+import java.sql.SQLException;
 import java.util.Properties;
 
 /**
@@ -39,7 +42,7 @@ import java.util.Properties;
  * 
  * @author Mark Matthews
  */
-public class StandardSocketFactory implements SocketFactory {
+public class StandardSocketFactory implements SocketFactory, SocketMetadata {
 
 	public static final String TCP_NO_DELAY_PROPERTY_NAME = "tcpNoDelay";
 
@@ -158,7 +161,7 @@ public class StandardSocketFactory implements SocketFactory {
 
 			if (trafficClass > 0 && setTraficClassMethod != null) {
 				setTraficClassMethod.invoke(sock,
-						new Object[] { new Integer(trafficClass) });
+						new Object[] { Integer.valueOf(trafficClass) });
 			}
 		} catch (Throwable t) {
 			unwrapExceptionToProperClassAndThrowIt(t);
@@ -317,7 +320,7 @@ public class StandardSocketFactory implements SocketFactory {
 								Object sockAddr = addrConstructor
 										.newInstance(new Object[] {
 												possibleAddresses[i],
-												new Integer(port) });
+												Integer.valueOf(port) });
 								// bind to the local port, null is 'ok', it
 								// means
 								// use the ephemeral port
@@ -326,7 +329,7 @@ public class StandardSocketFactory implements SocketFactory {
 
 								connectWithTimeoutMethod.invoke(rawSocket,
 										new Object[] { sockAddr,
-												new Integer(connectTimeout) });
+												Integer.valueOf(connectTimeout) });
 
 								break;
 							} catch (Exception ex) {	
@@ -404,4 +407,49 @@ public class StandardSocketFactory implements SocketFactory {
 
 		throw new SocketException(caughtWhileConnecting.toString());
 	}
+
+	public boolean isLocallyConnected(com.mysql.jdbc.ConnectionImpl conn) throws SQLException {
+		long threadId = conn.getId();
+		java.sql.Statement processListStmt = conn.getMetadataSafeStatement();
+		ResultSet rs = null;
+		
+		try {
+			String processHost = null;
+			
+			rs = processListStmt.executeQuery("SHOW PROCESSLIST");
+			
+			while (rs.next()) {
+				 long id = rs.getLong(1);
+
+                 if (threadId == id) {
+                	 processHost = rs.getString(3);
+                     
+                     break;
+                 }
+			}
+             
+             if (processHost != null) {
+                 if (processHost.indexOf(":") != -1) {
+                	 processHost = processHost.split(":")[0];
+
+                     try {
+                         boolean isLocal;
+
+                    	 isLocal = InetAddress.getByName(processHost).equals(
+                    			 rawSocket.getLocalAddress());
+
+                         return isLocal;
+                     } catch (UnknownHostException e) {
+                         conn.getLog().logWarn(Messages.getString("Connection.CantDetectLocalConnect", new Object[] {host}), e);
+
+                         return false;
+                     }
+                 }
+             }
+             
+             return false;
+		} finally {
+			processListStmt.close();
+		}
+	}
 }
\ No newline at end of file
