@@ -1,26 +1,24 @@
 /*
- Copyright  2002-2007 MySQL AB, 2008-2010 Sun Microsystems
- All rights reserved. Use is subject to license terms.
+ Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
+ 
 
-  The MySQL Connector/J is licensed under the terms of the GPL,
-  like most MySQL Connectors. There are special exceptions to the
-  terms and conditions of the GPL as it is applied to this software,
-  see the FLOSS License Exception available on mysql.com.
+  The MySQL Connector/J is licensed under the terms of the GPLv2
+  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
+  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
+  this software, see the FLOSS License Exception
+  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; version 2 of the
-  License.
+  This program is free software; you can redistribute it and/or modify it under the terms
+  of the GNU General Public License as published by the Free Software Foundation; version 2
+  of the License.
 
-  This program is distributed in the hope that it will be useful,  
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the GNU General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-  02110-1301 USA
+  You should have received a copy of the GNU General Public License along with this
+  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
+  Floor, Boston, MA 02110-1301  USA
 
 
 
@@ -207,6 +205,14 @@ public abstract class BaseTestCase extends TestCase {
 		dropSchemaObject("TABLE", tableName);
 	}
 
+	protected void createDatabase(String databaseName) throws SQLException {
+		createSchemaObject("DATABASE", databaseName, "");
+	}
+
+	protected void dropDatabase(String databaseName) throws SQLException {
+		dropSchemaObject("DATABASE", databaseName);
+	}
+
 	protected void dropSchemaObject(String objectType, String objectName)
 			throws SQLException {
 		this.stmt.executeUpdate("DROP " + objectType + " IF EXISTS "
@@ -637,30 +643,6 @@ public abstract class BaseTestCase extends TestCase {
 		}
 	}
 
-	protected void closeMemberJDBCResources() {
-		if (this.rs != null) {
-			ResultSet toClose = this.rs;
-			this.rs = null;
-
-			try {
-				toClose.close();
-			} catch (SQLException sqlEx) {
-				// ignore
-			}
-		}
-
-		if (this.pstmt != null) {
-			PreparedStatement toClose = this.pstmt;
-			this.pstmt = null;
-
-			try {
-				toClose.close();
-			} catch (SQLException sqlEx) {
-				// ignore
-			}
-		}
-	}
-
 	protected boolean isRunningOnJRockit() {
 		String vmVendor = System.getProperty("java.vm.vendor");
 
@@ -813,11 +795,19 @@ public abstract class BaseTestCase extends TestCase {
 	}
 
 	protected String getMasterSlaveUrl() throws SQLException {
-		StringBuffer urlBuf = new StringBuffer("jdbc:mysql://");
+		
 		Properties defaultProps = getPropertiesFromTestsuiteUrl();
 		String hostname = defaultProps
 				.getProperty(NonRegisteringDriver.HOST_PROPERTY_KEY);
 	
+		if (NonRegisteringDriver.isHostPropertiesList(hostname)) {
+			String url = String.format("jdbc:mysql://%s,%s/", hostname, hostname);
+			
+			return url;
+		}
+		
+		StringBuffer urlBuf = new StringBuffer("jdbc:mysql://");
+		
 		String portNumber = defaultProps.getProperty(NonRegisteringDriver.PORT_PROPERTY_KEY, "3306");
 	
 		hostname = (hostname == null ? "localhost" : hostname);
@@ -839,49 +829,70 @@ public abstract class BaseTestCase extends TestCase {
 	protected Properties getMasterSlaveProps() throws SQLException {
 		Properties props = getPropertiesFromTestsuiteUrl();
 	
-		props.remove(NonRegisteringDriver.HOST_PROPERTY_KEY);
-		props.remove(NonRegisteringDriver.PORT_PROPERTY_KEY);
+		removeHostRelatedProps(props);
 	
 		return props;
 	}
+	
+	protected void removeHostRelatedProps(Properties props) {
+		props.remove(NonRegisteringDriver.HOST_PROPERTY_KEY);
+		props.remove(NonRegisteringDriver.PORT_PROPERTY_KEY);
+		
+		int numHosts = Integer.parseInt(props.getProperty(NonRegisteringDriver.NUM_HOSTS_PROPERTY_KEY));
+		
+		for (int i = 1; i <= numHosts; i++) {
+			props.remove(NonRegisteringDriver.HOST_PROPERTY_KEY + "." + i);
+			props.remove(NonRegisteringDriver.PORT_PROPERTY_KEY + "." + i);
+		}
+		
+		props.remove(NonRegisteringDriver.NUM_HOSTS_PROPERTY_KEY);
+	}
 
 	protected Connection getLoadBalancedConnection(int badHostLocation, String badHost,
 			Properties props) throws SQLException {
-				int indexOfHostStart = dbUrl.indexOf("://") + 3;
-				int indexOfHostEnd = dbUrl.indexOf("/", indexOfHostStart);
-				
-				String firstHost = dbUrl.substring(indexOfHostStart, indexOfHostEnd);
-				
-				if (firstHost.length() == 0) {
-					firstHost = "localhost:3306";
-				}
-				
-				String dbAndConfigs = dbUrl.substring(indexOfHostEnd);
-				
-				if (badHost != null) {
-					badHost = badHost + ",";
-				}
-				
-				String hostsString = null;
-				
-				switch (badHostLocation) {
-				case 1:
-					hostsString = badHost + firstHost;
-					break;
-				case 2:
-					hostsString = firstHost + "," + badHost + firstHost;
-					break;
-				case 3:
-					hostsString = firstHost + "," + badHost;
-					break;
-				default:
-						throw new IllegalArgumentException();
-				}
-				
-				Connection lbConn = DriverManager.getConnection("jdbc:mysql:loadbalance://" + hostsString + dbAndConfigs, props);
-				
-				return lbConn;
+		Properties parsedProps = new NonRegisteringDriver().parseURL(dbUrl, null);
+		
+		String firstHost = parsedProps.getProperty(NonRegisteringDriver.HOST_PROPERTY_KEY);
+		
+		if (!NonRegisteringDriver.isHostPropertiesList(firstHost)) {
+			String port = parsedProps.getProperty(NonRegisteringDriver.PORT_PROPERTY_KEY, "3306");
+			
+			if (firstHost == null) {
+				firstHost = "localhost";
 			}
+			
+			
+			firstHost = firstHost + ":" + port;
+		}
+
+		if (badHost != null) {
+			badHost = badHost + ",";
+		}
+		
+		String hostsString = null;
+		
+		switch (badHostLocation) {
+		case 1:
+			hostsString = badHost + firstHost;
+			break;
+		case 2:
+			hostsString = firstHost + "," + badHost + firstHost;
+			break;
+		case 3:
+			hostsString = firstHost + "," + badHost;
+			break;
+		default:
+				throw new IllegalArgumentException();
+		}
+		
+		if (props != null) {
+			parsedProps.putAll(props);
+		}
+
+		Connection lbConn = DriverManager.getConnection("jdbc:mysql:loadbalance://" + hostsString, parsedProps);
+		
+		return lbConn;
+	}
 
 	protected Connection getLoadBalancedConnection() throws SQLException {
 		return getLoadBalancedConnection(1, "", null);
@@ -971,5 +982,41 @@ public abstract class BaseTestCase extends TestCase {
 					
 				return getConnectionWithProps("jdbc:mysql:loadbalance://" + hostString.toString() +"/" + db, props);
 				
+			}
+	protected Connection getUnreliableReplicationConnection(String[] hostNames,
+			Properties props) throws Exception {
+		return getUnreliableReplicationConnection(hostNames,
+				props, new HashSet());
+	}
+	protected Connection getUnreliableReplicationConnection(String[] hostNames,
+			Properties props, Set downedHosts) throws Exception {
+				if(props == null){
+					props = new Properties();
+				}
+				NonRegisteringDriver d = new NonRegisteringDriver();
+				this.copyBasePropertiesIntoProps(props, d);
+				props.setProperty("socketFactory", "testsuite.UnreliableSocketFactory");
+				Properties parsed = d.parseURL(BaseTestCase.dbUrl, props);
+				String db = parsed.getProperty(NonRegisteringDriver.DBNAME_PROPERTY_KEY);
+				String port = parsed.getProperty(NonRegisteringDriver.PORT_PROPERTY_KEY);
+				String host = getPortFreeHostname(props, d);
+				UnreliableSocketFactory.flushAllHostLists();
+				StringBuffer hostString = new StringBuffer();
+				String glue = "";
+				for(int i = 0; i < hostNames.length; i++){
+					UnreliableSocketFactory.mapHost(hostNames[i], host);
+					hostString.append(glue);
+					glue = ",";
+					hostString.append(hostNames[i] + ":" + (port == null ? "3306" : port));
+					
+					if (downedHosts.contains(hostNames[i])) {
+						UnreliableSocketFactory.downHost(hostNames[i]);
+					}
+				}
+				
+				props.remove(NonRegisteringDriver.HOST_PROPERTY_KEY);
+					
+				return getConnectionWithProps("jdbc:mysql:replication://" + hostString.toString() +"/" + db, props);
+				
 			}
 }
