@@ -1,26 +1,24 @@
 /*
- Copyright  2008 MySQL AB, 2008 Sun Microsystems
- All rights reserved. Use is subject to license terms.
+ Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ 
 
-  The MySQL Connector/J is licensed under the terms of the GPL,
-  like most MySQL Connectors. There are special exceptions to the
-  terms and conditions of the GPL as it is applied to this software,
-  see the FLOSS License Exception available on mysql.com.
+  The MySQL Connector/J is licensed under the terms of the GPLv2
+  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
+  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
+  this software, see the FLOSS License Exception
+  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; version 2 of the
-  License.
+  This program is free software; you can redistribute it and/or modify it under the terms
+  of the GNU General Public License as published by the Free Software Foundation; version 2
+  of the License.
 
-  This program is distributed in the hope that it will be useful,  
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the GNU General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-  02110-1301 USA
+  You should have received a copy of the GNU General Public License along with this
+  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
+  Floor, Boston, MA 02110-1301  USA
 
 
 
@@ -42,6 +40,9 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 
+import com.mysql.jdbc.NamedPipeSocketFactory;
+import com.mysql.jdbc.NonRegisteringDriver;
+import com.mysql.jdbc.SocketFactory;
 import com.mysql.jdbc.StandardSocketFactory;
 
 /**
@@ -137,6 +138,39 @@ public class UnreliableSocketFactory extends StandardSocketFactory {
 			hostnameToConnectTo = hostname;
 		}
 		
+		if (NonRegisteringDriver.isHostPropertiesList(hostnameToConnectTo)) {
+			Properties hostSpecificProps = NonRegisteringDriver.expandHostKeyValues(hostnameToConnectTo);
+			
+			String protocol = hostSpecificProps.getProperty(NonRegisteringDriver.PROTOCOL_PROPERTY_KEY);
+			
+			if ("unix".equalsIgnoreCase(protocol)) {
+				SocketFactory factory;
+				try {
+					factory = (SocketFactory) Class
+							.forName(
+									"org.newsclub.net.mysql.AFUNIXDatabaseSocketFactory")
+							.newInstance();
+				} catch (InstantiationException e) {
+					throw new SocketException(e.getMessage());
+				} catch (IllegalAccessException e) {
+					throw new SocketException(e.getMessage());
+				} catch (ClassNotFoundException e) {
+					throw new SocketException(e.getMessage());
+				}
+
+				String path = hostSpecificProps
+						.getProperty(NonRegisteringDriver.PATH_PROPERTY_KEY);
+
+				if (path != null) {
+					hostSpecificProps.setProperty("junixsocket.file", path);
+				}
+
+				return new HangingSocket(factory.connect(hostnameToConnectTo,
+						portNumber, hostSpecificProps), props, hostname);
+			}
+
+		}
+		
 		return new HangingSocket(super.connect(hostnameToConnectTo, portNumber, props), props, hostname);
 	}
 	
