@@ -3079,4 +3079,56 @@ public class ConnectionRegressionTest extends BaseTestCase {
 			}
 		}
 	}
+	
+	public void testStatementComment() throws Exception {
+		Connection c = getConnectionWithProps("autoGenerateTestcaseScript=true,logger=StandardLogger");
+		PrintStream oldErr = System.err;
+		
+		try {
+			ByteArrayOutputStream bOut = new ByteArrayOutputStream();
+			PrintStream printStream = new PrintStream(bOut);
+			System.setErr(printStream);
+			
+			((com.mysql.jdbc.Connection)c).setStatementComment("Hi there");
+			c.setAutoCommit(false);
+			
+			c.createStatement().execute("SELECT 1");
+			c.commit();
+			c.rollback();
+			Pattern pattern = Pattern.compile("Hi");
+			String loggedData = new String(bOut.toByteArray());
+			Matcher matcher = pattern.matcher(loggedData);
+			int count = 0;
+			while (matcher.find()) {
+				count++;
+			}
+			
+			assertEquals(4, count);
+		} finally {
+			System.setErr(oldErr);
+		}
+	}
+	
+	public void testReconnectWithCachedConfig() throws Exception {
+		Connection rConn = getConnectionWithProps("autoReconnect=true,initialTimeout=2,maxReconnects=3,cacheServerConfiguration=true,elideSetAutoCommits=true");
+		String threadId = getSingleIndexedValueWithQuery(rConn, 1, "select connection_id()").toString();
+		killConnection(this.conn, threadId);
+		boolean detectedDeadConn = false;
+		
+		for (int i = 0; i < 100; i++) {
+			try {
+				rConn.createStatement().executeQuery("SELECT 1");
+			} catch (SQLException sqlEx) {
+				detectedDeadConn = true;
+				break;
+			}
+		}
+		
+		assertTrue(detectedDeadConn);
+		rConn.prepareStatement("SELECT 1").executeQuery();
+		
+		Connection rConn2 = getConnectionWithProps("autoReconnect=true,initialTimeout=2,maxReconnects=3,cacheServerConfiguration=true,elideSetAutoCommits=true");
+		rConn2.prepareStatement("SELECT 1").executeQuery();
+		
+	}
 }
\ No newline at end of file
