@@ -1,26 +1,24 @@
 /*
- Copyright  2002-2004 MySQL AB, 2008 Sun Microsystems
- All rights reserved. Use is subject to license terms.
+ Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
+ 
 
-  The MySQL Connector/J is licensed under the terms of the GPL,
-  like most MySQL Connectors. There are special exceptions to the
-  terms and conditions of the GPL as it is applied to this software,
-  see the FLOSS License Exception available on mysql.com.
+  The MySQL Connector/J is licensed under the terms of the GPLv2
+  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
+  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
+  this software, see the FLOSS License Exception
+  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; version 2 of the
-  License.
+  This program is free software; you can redistribute it and/or modify it under the terms
+  of the GNU General Public License as published by the Free Software Foundation; version 2
+  of the License.
 
-  This program is distributed in the hope that it will be useful,  
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the GNU General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-  02110-1301 USA
+  You should have received a copy of the GNU General Public License along with this
+  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
+  Floor, Boston, MA 02110-1301  USA
 
 
 
@@ -109,25 +107,10 @@ public class BlobTest extends BaseTestCase {
 		createTestTable();
 	}
 
-	/**
-	 * Destroy resources created by test case
-	 * 
-	 * @throws Exception
-	 *             if an error occurs
-	 */
-	public void tearDown() throws Exception {
-		try {
-			this.stmt.executeUpdate("DROP TABLE IF EXISTS BLOBTEST");
-		} catch (Exception e) {
-			e.printStackTrace();
-		} finally {
-			super.tearDown();
-		}
-	}
-
 	public void testByteStreamInsert() throws Exception {
 		testByteStreamInsert(this.conn);
 	}
+	
 	/**
 	 * Tests inserting blob data as a stream
 	 * 
@@ -188,17 +171,7 @@ public class BlobTest extends BaseTestCase {
 	}
 
 	private void createTestTable() throws Exception {
-		//
-		// Catch the error, the table might exist
-		//
-		try {
-			this.stmt.executeUpdate("DROP TABLE BLOBTEST");
-		} catch (SQLException SQLE) {
-			;
-		}
-
-		this.stmt
-				.executeUpdate("CREATE TABLE BLOBTEST (pos int PRIMARY KEY auto_increment, "
+		createTable("BLOBTEST", "(pos int PRIMARY KEY auto_increment, "
 						+ "blobdata LONGBLOB)");
 	}
 
