@@ -1,26 +1,24 @@
 /*
- Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
- All rights reserved. Use is subject to license terms.
+ Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
+ 
 
-  The MySQL Connector/J is licensed under the terms of the GPL,
-  like most MySQL Connectors. There are special exceptions to the
-  terms and conditions of the GPL as it is applied to this software,
-  see the FLOSS License Exception available on mysql.com.
+  The MySQL Connector/J is licensed under the terms of the GPLv2
+  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
+  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
+  this software, see the FLOSS License Exception
+  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; version 2 of the
-  License.
+  This program is free software; you can redistribute it and/or modify it under the terms
+  of the GNU General Public License as published by the Free Software Foundation; version 2
+  of the License.
 
-  This program is distributed in the hope that it will be useful,  
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the GNU General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-  02110-1301 USA
+  You should have received a copy of the GNU General Public License along with this
+  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
+  Floor, Boston, MA 02110-1301  USA
 
 
 
@@ -102,10 +100,13 @@ public class DataSourceTest extends BaseTestCase {
 	 *             if an error occurs
 	 */
 	public void tearDown() throws Exception {
-		this.ctx.unbind(this.tempDir.getAbsolutePath() + "/test");
-		this.ctx.close();
-		this.tempDir.delete();
-		super.tearDown();
+		try {
+			this.ctx.unbind(this.tempDir.getAbsolutePath() + "/test");
+			this.ctx.close();
+			this.tempDir.delete();
+		} finally {
+			super.tearDown();
+		}
 	}
 
 	/**
@@ -183,7 +184,9 @@ public class DataSourceTest extends BaseTestCase {
 			this.rs = connToMySQL.createStatement().executeQuery(
 					"SHOW SESSION VARIABLES LIKE 'character_set_client'");
 			assertTrue(this.rs.next());
-			assertEquals("utf8", this.rs.getString(2));
+			
+			//Cause of utf8mb4
+			assertEquals(0, this.rs.getString(2).indexOf("utf8"));
 
 			connToMySQL.close();
 
@@ -196,7 +199,9 @@ public class DataSourceTest extends BaseTestCase {
 			this.rs = connToMySQL.createStatement().executeQuery(
 					"SHOW SESSION VARIABLES LIKE 'character_set_client'");
 			assertTrue(this.rs.next());
-			assertEquals("utf8", this.rs.getString(2));
+
+			//Cause of utf8mb4
+			assertEquals(0, this.rs.getString(2).indexOf("utf8"));
 
 			pooledConnection.getConnection().close();
 		}
